@@ -1,4 +1,5 @@
-# Copyright (c) 2018 Kevin Murray <kdmfoss@gmail.com>
+# Copyright (c) 2018-2021 Kevin Murray <foss@kdmurray.id.au>
+#
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -6,11 +7,13 @@
 from .base import (
     ResultRecorder,
     TSPipeline,
-    CopyStep,
     WriteFileStep,
     ResultRecorderStep,
     FileStatsStep,
     TeeStep,
+    FilterStep,
+    ConditionalStep,
+    ClearFileObjectStep,
 )
 from .audit import (
     ImageMeanColourStep,
@@ -28,17 +31,23 @@ from .imageio import (
     EncodeImageFileStep,
 )
 from .rmscript import WriteRmScriptStep
-from .telegraf import TelegrafRecordStep
+from .roitracker import (
+    ROIMaskManager,
+    ROIPipelineStep,
+)
 from .verify import UnsafeNuker
 
+
 __all__ = [
     "ResultRecorder",
     "TSPipeline",
-    "CopyStep",
     "WriteFileStep",
     "ResultRecorderStep",
     "FileStatsStep",
     "TeeStep",
+    "FilterStep",
+    "ConditionalStep",
+    "ClearFileObjectStep",
     "ImageMeanColourStep",
     "ScanQRCodesStep",
     "CalculateEVStep",
@@ -49,6 +58,7 @@ __all__ = [
     "EncodeImageFileStep",
     "TruncateTimeStep",
     "WriteRmScriptStep",
-    "TelegrafRecordStep",
     "UnsafeNuker",
+    "ROIMaskManager",
+    "ROIPipelineStep",
 ]
