@@ -396,7 +396,7 @@ class TimeStream(object):
         if bundle_level not in self.bundle_levels:
             raise ValueError("invalid bundle level %s",  bundle_level)
         self.bundle = bundle_level
-        self._index_file = None
+        self._index_file = ""
         if path is not None:
             self.open(path, format=format)
             if bundle_level == "root" or op.isfile(self.path):
@@ -446,25 +446,25 @@ class TimeStream(object):
                 print("Failed to load index file:", str(exc), file=stderr)
                 if stderr.isatty():
                     traceback.print_exc(file=stderr)
-            with FileLock(self._index_file):
-                try:
-                    itr = self.iter(tar_contents=False)
-                    if progress:
-                        itr = tqdm(itr)
-                    if self.write_index:
-                        with open(self._index_file, "w") as fh:
-                            for f in itr:
-                                self._instants[f.instant] = f.fetcher
-                                print(json.dumps(f.fetcher.dict(), cls=PathAwareJsonEncoder), file=fh)
-                    else:
-                        for f in itr:
-                            self._instants[f.instant] = f.fetcher
-                except Exception as exc:
-                    print("Failed to create timestream index file:", str(exc), file=stderr)
-                    if stderr.isatty():
-                        traceback.print_exc(file=stderr)
-                    if op.exists(self._index_file):
-                        os.unlink(self._index_file)
+            itr = self.iter(tar_contents=False)
+            if self.write_index:
+                with FileLock(self._index_file):
+                    try:
+                        if progress:
+                            itr = tqdm(itr)
+                            with open(self._index_file, "w") as fh:
+                                for f in itr:
+                                    self._instants[f.instant] = f.fetcher
+                                    print(json.dumps(f.fetcher.dict(), cls=PathAwareJsonEncoder), file=fh)
+                    except Exception as exc:
+                        print("Failed to create timestream index file:", str(exc), file=stderr)
+                        if stderr.isatty():
+                            traceback.print_exc(file=stderr)
+                        if op.exists(self._index_file):
+                            os.unlink(self._index_file)
+            else:
+                for f in itr:
+                    self._instants[f.instant] = f.fetcher
 
     @property
     def instants(self):
@@ -689,7 +689,7 @@ class TimeStream(object):
         if not isinstance(file, TimestreamFile):
             raise TypeError("file should be a TimestreamFile")
         subpath = self._timestream_path(file)
-        if self.bundle == "none":
+        if (self.bundle == "none") and (self.path is not None):
             outpath = op.join(self.path, subpath)
             os.makedirs(op.dirname(outpath), exist_ok=True)
             with FileLock(outpath):
